pycbg.preprocessing.Simulation
==============================

.. currentmodule:: pycbg.preprocessing

.. autoclass:: Simulation
   :members:

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Simulation.__init__
      ~Simulation.add_friction_condition
      ~Simulation.add_math_function
      ~Simulation.add_nodal_force
      ~Simulation.add_velocity_condition
      ~Simulation.create_mesh
      ~Simulation.create_particles
      ~Simulation.init_entity_sets
      ~Simulation.set_analysis_parameters
      ~Simulation.set_gravity
      ~Simulation.set_initial_particles_stresses
      ~Simulation.write_input_file
   
   

   
   
   